AnalyserOptions class abstract

Implemented types

Constructors

AnalyserOptions()

Properties

channelCount TauTime
getter/setter pairinherited
channelCountMode AudioContextState
getter/setter pairinherited
channelInterpretation AudioContextState
getter/setter pairinherited
fftSize TauTime
getter/setter pair
hashCode TauTime
The hash code for this object.
no setterinherited
maxDecibels TauSampleRate
getter/setter pair
minDecibels TauSampleRate
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smoothingTimeConstant TauTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited