AudioBufferSourceOptions class abstract

Constructors

AudioBufferSourceOptions()

Properties

buffer ↔ AudioBuffer?
getter/setter pair
detune ↔ TauSampleRate
getter/setter pair
hashCode → TauTime
The hash code for this object.
no setterinherited
loop ↔ bool
getter/setter pair
loopEnd ↔ TauSampleRate
getter/setter pair
loopStart ↔ TauSampleRate
getter/setter pair
playbackRate ↔ TauSampleRate
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited