AudioDestinationNode class abstract
The AudioDestinationNode represents the end destination of an
audio graph in a given context — usually the speakers of your device. It can
also be the node that will "record" the audio data when used with an
OfflineAudioContext.
AudioDestinationNode has no output (as it is the output, no more
AudioNode can be linked after it in the audio graph) and one input. The
number of channels in the input must be between 0 and the
maxChannelCount value or an exception is raised.
The AudioDestinationNode of a given AudioContext can be retrieved using
the BaseAudioContext.destination property.
| Number of inputs | 1 |
|---|---|
| Number of outputs | 0 |
| Channel count mode | "explicit" |
| Channel count | 2 |
| Channel interpretation | "speakers" |
API documentation sourced from MDN Web Docs.
- Implemented types
Constructors
Properties
- channelCount ↔ int
-
The
channelCountproperty of the AudioNode represents an integer used to determine how many channels are used when up-mixing and down-mixing connections to any inputs to the node.getter/setter pairinherited - channelCountMode ↔ ChannelCountMode
-
The
channelCountModeproperty of the AudioNode represents an enumerated value describing the way channels must be matched between the node's inputs and outputs.getter/setter pairinherited - channelInterpretation ↔ ChannelInterpretation
-
The
channelInterpretationproperty of the AudioNode interface represents an enumerated value describing how input channels are mapped to output channels when the number of inputs/outputs is different. For example, this setting defines how a mono input will be up-mixed to a stereo or 5.1 channel output, or how a quad channel input will be down-mixed to a stereo or mono output.getter/setter pairinherited - context → BaseAudioContext
-
The read-only
contextproperty of the AudioNode returns the associated BaseAudioContext, that is the object representing the processing graph the node is participating in.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- maxChannelCount → int
-
The
maxchannelCountproperty of the AudioDestinationNode is anunsigned longdefining the maximum amount of channels that the physical device can handle.no setter - numberOfInputs → int
-
The
numberOfInputsproperty of the AudioNode returns the number of inputs feeding the node. Source nodes are defined as nodes having anumberOfInputsproperty with a value of 0.no setterinherited - numberOfOutputs → int
-
The
numberOfOutputsproperty of the AudioNode returns the number of outputs coming out of the node. Destination nodes — like AudioDestinationNode — have a value of 0 for this attribute.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
AudioNode destinationNode, [int output, int input]) → AudioNode -
The
connect()method of the AudioNode lets you connect one of the node's outputs to a target, which may be either anotherAudioNode(thereby directing the sound data to the specified node). See also AudioNode.connectParaminherited -
connectParam(
AudioParam destinationParam, [int output, int input]) → void -
This is a variant of AudioNode.connect with a
DestinationParamargument instead of anAudioNode. Note : The W3C recommandation uses just one verb for both.inherited -
disconnect(
[AudioNode destinationParamOrOutput, int output, int input]) → void -
The
disconnect()method of the AudioNode lets you disconnect one or more nodes from the node on which the method is called. See also AudioNode.disconnectParaminherited -
disconnectParam(
AudioParam destinationParam, [int output, int input]) → void -
This is a variant of AudioNode.disconnect with a
DestinationParamargument instead of anAudioNode. Note : The W3C recommandation uses just one verb for both.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited