AudioListener class abstract
The AudioListener represents the position and orientation of the
unique person listening to the audio scene, and is used in
audio spatialization.
All PannerNodes spatialize in relation to the AudioListener stored in
the BaseAudioContext.listener attribute.
It is important to note that there is only one listener per context and that it isn't an AudioNode.

API documentation sourced from MDN Web Docs.
Constructors
Properties
- forwardX → AudioParam
-
The
forwardXread-only property of the AudioListener is an AudioParam representing the x value of the direction vector defining the forward direction the listener is pointing in.no setter - forwardY → AudioParam
-
The
forwardYread-only property of the AudioListener is an AudioParam representing the y value of the direction vector defining the forward direction the listener is pointing in.no setter - forwardZ → AudioParam
-
The
forwardZread-only property of the AudioListener is an AudioParam representing the z value of the direction vector defining the forward direction the listener is pointing in.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- positionX → AudioParam
-
The
positionXread-only property of the AudioListener is an AudioParam representing the x position of the listener in 3D cartesian space.no setter - positionY → AudioParam
-
The
positionYread-only property of the AudioListener is an AudioParam representing the y position of the listener in 3D cartesian space.no setter - positionZ → AudioParam
-
The
positionZread-only property of the AudioListener is an AudioParam representing the z position of the listener in 3D cartesian space.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upX → AudioParam
-
The
upXread-only property of the AudioListener is an AudioParam representing the x value of the direction vector defining the up direction the listener is pointing in.no setter - upY → AudioParam
-
The
upYread-only property of the AudioListener is an AudioParam representing the y value of the direction vector defining the up direction the listener is pointing in.no setter - upZ → AudioParam
-
The
upZread-only property of the AudioListener is an AudioParam representing the z value of the direction vector defining the up direction the listener is pointing in.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setOrientation(
num x, num y, num z, num xUp, num yUp, num zUp) → void -
The
setOrientation()method of the AudioListener defines the orientation of the listener. -
setPosition(
num x, num y, num z) → void -
The
setPosition()method of the AudioListener defines the position of the listener. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited