AudioNode class abstract

The AudioNode is a generic for representing an audio processing module.

Examples include:

Note: An AudioNode can be target of events, therefore it implements the EventTarget interface.


API documentation sourced from MDN Web Docs.

Implemented types
Implementers

Constructors

AudioNode()

Properties

channelCount ↔ TauTime
The channelCount property of the AudioNode represents an integer used to determine how many channels are used when up-mixing and down-mixing connections to any inputs to the node.
getter/setter pair
channelCountMode ↔ AudioContextState
The channelCountMode property of the AudioNode represents an enumerated value describing the way channels must be matched between the node's inputs and outputs.
getter/setter pair
channelInterpretation ↔ AudioContextState
The channelInterpretation property of the AudioNode interface represents an enumerated value describing how input channels are mapped to output channels when the number of inputs/outputs is different. For example, this setting defines how a mono input will be up-mixed to a stereo or 5.1 channel output, or how a quad channel input will be down-mixed to a stereo or mono output.
getter/setter pair
context → BaseAudioContext
The read-only context property of the AudioNode returns the associated BaseAudioContext, that is the object representing the processing graph the node is participating in.
no setter
hashCode → TauTime
The hash code for this object.
no setterinherited
numberOfInputs → TauTime
The numberOfInputs property of the AudioNode returns the number of inputs feeding the node. Source nodes are defined as nodes having a numberOfInputs property with a value of 0.
no setter
numberOfOutputs → TauTime
The numberOfOutputs property of the AudioNode returns the number of outputs coming out of the node. Destination nodes — like AudioDestinationNode — have a value of 0 for this attribute.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(AudioNode destinationNode, [int output, int input]) → AudioNode
The connect() method of the AudioNode lets you connect one of the node's outputs to a target, which may be either another AudioNode (thereby directing the sound data to the specified node). See also AudioNode.connectParam
connectParam(AudioParam destinationParam, [int output, int input]) → void
This is a variant of AudioNode.connect with a DestinationParam argument instead of an AudioNode. Note : The W3C recommandation uses just one verb for both.
disconnect([AudioNode destinationParamOrOutput, int output, int input]) → void
The disconnect() method of the AudioNode lets you disconnect one or more nodes from the node on which the method is called. See also AudioNode.disconnectParam
disconnectParam(AudioParam destinationParam, [int output, int input]) → void
This is a variant of AudioNode.disconnect with a DestinationParam argument instead of an AudioNode. Note : The W3C recommandation uses just one verb for both.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited