connect abstract method
The connect() method of the AudioNode lets
you connect one of the node's outputs to a target, which may be either
another
AudioNode (thereby directing the sound data to the specified node).
See also AudioNode.connectParam
Implementation
AudioNode connect(
AudioNode destinationNode, [
int output,
int input,
]);