AudioParamMap class abstract

The AudioParamMap of the Web Audio API represents an iterable and read-only set of multiple audio parameters.

An AudioParamMap instance is a read-only Map-like object, in which each key is the name string for a parameter, and the corresponding value is an AudioParam containing the value of that parameter.


API documentation sourced from MDN Web Docs.

Constructors

AudioParamMap()

Properties

hashCode → TauTime
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProperty(String key) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(String key, dynamic value) → void
toString() → AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited