AudioWorkletNodeOptions class abstract

Implemented types

Constructors

AudioWorkletNodeOptions()

Properties

channelCount ↔ TauTime
getter/setter pairinherited
channelCountMode ↔ AudioContextState
getter/setter pairinherited
channelInterpretation ↔ AudioContextState
getter/setter pairinherited
hashCode → TauTime
The hash code for this object.
no setterinherited
numberOfInputs ↔ TauTime
getter/setter pair
numberOfOutputs ↔ TauTime
getter/setter pair
outputChannelCount ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited