knee property
AudioParam
get
knee
The knee property of the DynamicsCompressorNode is a
k-rate
AudioParam containing a decibel value representing the range above the
threshold where the curve smoothly transitions to the compressed portion.
The knee property's default value is 30 and it can be set between 0
and 40.

Implementation
AudioParam get knee;