DynamicsCompressorOptions class abstract

Implemented types

Constructors

DynamicsCompressorOptions()

Properties

attack TauSampleRate
getter/setter pair
channelCount TauTime
getter/setter pairinherited
channelCountMode AudioContextState
getter/setter pairinherited
channelInterpretation AudioContextState
getter/setter pairinherited
hashCode TauTime
The hash code for this object.
no setterinherited
knee TauSampleRate
getter/setter pair
ratio TauSampleRate
getter/setter pair
release TauSampleRate
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold TauSampleRate
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited