IIRFilterOptions class abstract

Implemented types

Constructors

IIRFilterOptions()

Properties

channelCount TauTime
getter/setter pairinherited
channelCountMode AudioContextState
getter/setter pairinherited
channelInterpretation AudioContextState
getter/setter pairinherited
feedback TauArray<TauNumber>
getter/setter pair
feedforward TauArray<TauNumber>
getter/setter pair
hashCode TauTime
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited