MediaElement class abstract

Constructors

MediaElement({required String src})

Properties

crossorigin ↔ String?
getter/setter pair
currentTime ↔ TauTime
getter/setter pair
hashCode → TauTime
The hash code for this object.
no setterinherited
loop ↔ bool
getter/setter pair
onplay ← EventHandler?
no getter
playbackRate ↔ TauSampleRate
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src ↔ AudioContextState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → dynamic
paused() → bool
play() → TauPromise<TauAny?>
toString() → AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited