MediaRecorder class abstract
Constructors
- MediaRecorder(MediaStream stream, String mimeType, [MediaRecorderOptions? options])
Properties
- audioBitsPerSecond → int
-
The
audioBitsPerSecondread-only property of the MediaRecorder interface returns the audio encoding bit rate in use.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
The
mimeTyperead-only property of the MediaRecorder interface returns the media type that was specified when creating the MediaRecorder object, or, if none was specified, which was chosen by the browser. This is the file format of the file that would result from writing all of the recorded data to disk.no setter - ondataavailable ← EventHandler
-
no getter
- onerror ← EventHandler
-
no getter
- onpause ← EventHandler
-
no getter
- onresume ← EventHandler
-
no getter
- onstart ← EventHandler
-
no getter
- onstop ← EventHandler
-
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → RecordingState
-
The
stateread-only property of the MediaRecorder interface returns the current state of the currentMediaRecorderobject.no setter - stream → MediaStream
-
The
streamread-only property of the MediaRecorder interface returns the stream that was passed into theMediaRecorder.MediaRecorderconstructor when theMediaRecorderwas created.no setter - videoBitsPerSecond → int
-
The
videoBitsPerSecondread-only property of the MediaRecorder interface returns the video encoding bit rate in use.no setter
Methods
-
isTypeSupported(
String type) → bool -
The
isTypeSupported()static method of the MediaRecorder interface returns aBooleanwhich istrueif the MIME media type specified is one the user agent should be able to successfully record. -
makeBuffer(
) → Future< ByteBuffer> - Specific τ
-
makeFile(
String fileName) → void - Specific τ
-
makeUrl(
) → String - Specific τ
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void -
The
pause()method of the MediaRecorder interface is used to pause recording of media streams. -
requestData(
) → void -
The
requestData()method of the MediaRecorder interface is used to raise aMediaRecorder.dataavailable_eventevent containing a Blob object of the captured media as it was when the method was called. This can then be grabbed and manipulated as you wish. -
resume(
) → void -
The
resume()method of the MediaRecorder interface is used to resume media recording when it has been previously paused. -
start(
[int timeslice]) → void -
The
start()method of the MediaRecorder interface begins recording media into one or more Blob objects. -
stop(
) → void -
The
stop()method of the MediaRecorder interface is used to stop media capture. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited