MediaRecorderOptions class abstract

Constructors

MediaRecorderOptions({String? mimeType, int? audioBitsPerSecond, int? videoBitsPerSecond, int? bitsPerSecond, BitrateMode? audioBitrateMode, DOMHighResTimeStamp? videoKeyFrameIntervalDuration, int? videoKeyFrameIntervalCount})

Properties

audioBitrateMode AudioContextState
getter/setter pair
audioBitsPerSecond TauTime
getter/setter pair
bitsPerSecond TauTime
getter/setter pair
hashCode TauTime
The hash code for this object.
no setterinherited
mimeType AudioContextState
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoBitsPerSecond TauTime
getter/setter pair
videoKeyFrameIntervalCount TauTime
getter/setter pair
videoKeyFrameIntervalDuration TauTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited