MediaStreamAudioSourceOptions class abstract

Properties

hashCode TauTime
The hash code for this object.
no setterinherited
mediaStream MediaStream
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited