OscillatorNode class abstract

The OscillatorNode represents a periodic waveform, such as a sine wave. It is an AudioScheduledSourceNode audio-processing module that causes a specified frequency of a given wave to be created—in effect, a constant tone.

Number of inputs 0
Number of outputs 1
Channel count mode max
Channel count 2 (not used in the default count mode)
Channel interpretation speakers

API documentation sourced from MDN Web Docs.

Implemented types

Constructors

OscillatorNode()

Properties

channelCount ↔ TauTime
The channelCount property of the AudioNode represents an integer used to determine how many channels are used when up-mixing and down-mixing connections to any inputs to the node.
getter/setter pairinherited
channelCountMode ↔ AudioContextState
The channelCountMode property of the AudioNode represents an enumerated value describing the way channels must be matched between the node's inputs and outputs.
getter/setter pairinherited
channelInterpretation ↔ AudioContextState
The channelInterpretation property of the AudioNode interface represents an enumerated value describing how input channels are mapped to output channels when the number of inputs/outputs is different. For example, this setting defines how a mono input will be up-mixed to a stereo or 5.1 channel output, or how a quad channel input will be down-mixed to a stereo or mono output.
getter/setter pairinherited
context → BaseAudioContext
The read-only context property of the AudioNode returns the associated BaseAudioContext, that is the object representing the processing graph the node is participating in.
no setterinherited
detune → AudioParam
The detune property of the OscillatorNode is an a-rate AudioParam representing detuning of oscillation in cents.
no setter
frequency → AudioParam
The frequency property of the OscillatorNode is an a-rate AudioParam representing the frequency of oscillation in hertz.
no setter
hashCode → TauTime
The hash code for this object.
no setterinherited
numberOfInputs → TauTime
The numberOfInputs property of the AudioNode returns the number of inputs feeding the node. Source nodes are defined as nodes having a numberOfInputs property with a value of 0.
no setterinherited
numberOfOutputs → TauTime
The numberOfOutputs property of the AudioNode returns the number of outputs coming out of the node. Destination nodes — like AudioDestinationNode — have a value of 0 for this attribute.
no setterinherited
onended ↔ EventHandler
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ AudioContextState
The type property of the OscillatorNode specifies what shape of waveform the oscillator will output. There are several common waveforms available, as well as an option to specify a custom waveform shape. The shape of the waveform will affect the tone that is produced.
getter/setter pair

Methods

connect(AudioNode destinationNode, [int output, int input]) → AudioNode
The connect() method of the AudioNode lets you connect one of the node's outputs to a target, which may be either another AudioNode (thereby directing the sound data to the specified node). See also AudioNode.connectParam
inherited
connectParam(AudioParam destinationParam, [int output, int input]) → void
This is a variant of AudioNode.connect with a DestinationParam argument instead of an AudioNode. Note : The W3C recommandation uses just one verb for both.
inherited
disconnect([AudioNode destinationParamOrOutput, int output, int input]) → void
The disconnect() method of the AudioNode lets you disconnect one or more nodes from the node on which the method is called. See also AudioNode.disconnectParam
inherited
disconnectParam(AudioParam destinationParam, [int output, int input]) → void
This is a variant of AudioNode.disconnect with a DestinationParam argument instead of an AudioNode. Note : The W3C recommandation uses just one verb for both.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPeriodicWave(PeriodicWave periodicWave) → void
The setPeriodicWave() method of the OscillatorNode is used to point to a PeriodicWave defining a periodic waveform that can be used to shape the oscillator's output, when OscillatorNode.type is custom.
start([num when]) → void
The start() method on AudioScheduledSourceNode schedules a sound to begin playback at the specified time. If no time is specified, then the sound begins playing immediately.
inherited
stop([num when]) → void
The stop() method on AudioScheduledSourceNode schedules a sound to cease playback at the specified time. If no time is specified, then the sound stops playing immediately.
inherited
toString() → AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited