OscillatorOptions class abstract

Implemented types

Constructors

OscillatorOptions()

Properties

channelCount TauTime
getter/setter pairinherited
channelCountMode AudioContextState
getter/setter pairinherited
channelInterpretation AudioContextState
getter/setter pairinherited
detune TauSampleRate
getter/setter pair
frequency TauSampleRate
getter/setter pair
hashCode TauTime
The hash code for this object.
no setterinherited
periodicWave PeriodicWave
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AudioContextState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() AudioContextState
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited