PannerNode class abstract
The PannerNode defines an audio-processing object that
represents the location, direction, and behavior of an audio source signal
in a simulated physical space. This AudioNode uses right-hand Cartesian
coordinates to describe the source's position as a vector and its
orientation as a 3D directional cone.
A PannerNode always has exactly one input and one output: the input can be
mono or stereo but the output is always stereo (2 channels); you can't
have panning effects without at least two audio channels!

| Number of inputs | 1 |
|---|---|
| Number of outputs | 1 |
| Channel count mode | "clamped-max" |
| Channel count | 2 |
| Channel interpretation | "speakers" |
API documentation sourced from MDN Web Docs.
- Implemented types
Constructors
Properties
- channelCount ↔ int
-
The
channelCountproperty of the AudioNode represents an integer used to determine how many channels are used when up-mixing and down-mixing connections to any inputs to the node.getter/setter pairinherited - channelCountMode ↔ ChannelCountMode
-
The
channelCountModeproperty of the AudioNode represents an enumerated value describing the way channels must be matched between the node's inputs and outputs.getter/setter pairinherited - channelInterpretation ↔ ChannelInterpretation
-
The
channelInterpretationproperty of the AudioNode interface represents an enumerated value describing how input channels are mapped to output channels when the number of inputs/outputs is different. For example, this setting defines how a mono input will be up-mixed to a stereo or 5.1 channel output, or how a quad channel input will be down-mixed to a stereo or mono output.getter/setter pairinherited - coneInnerAngle ↔ double
-
The
coneInnerAngleproperty of the PannerNode is a double value describing the angle, in degrees, of a cone inside of which there will be no volume reduction.getter/setter pair - coneOuterAngle ↔ double
-
The
coneOuterAngleproperty of the PannerNode is a double value describing the angle, in degrees, of a cone outside of which the volume will be reduced by a constant value, defined by the PannerNode.coneOuterGain property.getter/setter pair - coneOuterGain ↔ double
-
The
coneOuterGainproperty of the PannerNode is a double value, describing the amount of volume reduction outside the cone, defined by the PannerNode.coneOuterAngle attribute.getter/setter pair - context → BaseAudioContext
-
The read-only
contextproperty of the AudioNode returns the associated BaseAudioContext, that is the object representing the processing graph the node is participating in.no setterinherited - distanceModel ↔ DistanceModelType
-
The
distanceModelproperty of the PannerNode is an enumerated value determining which algorithm to use to reduce the volume of the audio source as it moves away from the listener.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- maxDistance ↔ double
-
The
maxDistanceproperty of the PannerNode is a double value representing the maximum distance between the audio source and the listener, after which the volume is not reduced any further. This value is used only by thelineardistance model.getter/setter pair - numberOfInputs → int
-
The
numberOfInputsproperty of the AudioNode returns the number of inputs feeding the node. Source nodes are defined as nodes having anumberOfInputsproperty with a value of 0.no setterinherited - numberOfOutputs → int
-
The
numberOfOutputsproperty of the AudioNode returns the number of outputs coming out of the node. Destination nodes — like AudioDestinationNode — have a value of 0 for this attribute.no setterinherited - orientationX → AudioParam
-
The
orientationXproperty of the PannerNode indicates the X (horizontal) component of the direction in which the audio source is facing, in a 3D Cartesian coordinate space.no setter - orientationY → AudioParam
-
The
orientationYproperty of the PannerNode interface indicates the Y (vertical) component of the direction the audio source is facing, in 3D Cartesian coordinate space.no setter - orientationZ → AudioParam
-
The
orientationZproperty of the PannerNode interface indicates the Z (depth) component of the direction the audio source is facing, in 3D Cartesian coordinate space.no setter - panningModel ↔ PanningModelType
-
The
panningModelproperty of the PannerNode is an enumerated value determining which spatialization algorithm to use to position the audio in 3D space.getter/setter pair - positionX → AudioParam
-
The
positionXproperty of the PannerNode specifies the X coordinate of the audio source's position in 3D Cartesian coordinates, corresponding to the horizontal axis (left-right).no setter - positionY → AudioParam
-
The
positionYproperty of the PannerNode specifies the Y coordinate of the audio source's position in 3D Cartesian coordinates, corresponding to the vertical axis (top-bottom). The complete vector is defined by the position of the audio source, given as (PannerNode.positionX, PannerNode.positionY, PannerNode.positionZ), and the orientation of the audio source (that is, the direction in which it's facing), given as (PannerNode.orientationX, PannerNode.orientationY, PannerNode.orientationZ).no setter - positionZ → AudioParam
-
The
positionZproperty of the PannerNode specifies the Z coordinate of the audio source's position in 3D Cartesian coordinates, corresponding to the depth axis (behind-in front of the listener). The complete vector is defined by the position of the audio source, given as (PannerNode.positionX, PannerNode.positionY, PannerNode.positionZ), and the orientation of the audio source (that is, the direction in which it's facing), given as (PannerNode.orientationX, PannerNode.orientationY, PannerNode.orientationZ).no setter - refDistance ↔ double
-
The
refDistanceproperty of the PannerNode is a double value representing the reference distance for reducing volume as the audio source moves further from the listener – i.e. the distance at which the volume reduction starts taking effect. This value is used by all distance models.getter/setter pair - rolloffFactor ↔ double
-
The
rolloffFactorproperty of the PannerNode is a double value describing how quickly the volume is reduced as the source moves away from the listener. This value is used by all distance models. TherolloffFactorproperty's default value is1.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
AudioNode destinationNode, [int output, int input]) → AudioNode -
The
connect()method of the AudioNode lets you connect one of the node's outputs to a target, which may be either anotherAudioNode(thereby directing the sound data to the specified node). See also AudioNode.connectParaminherited -
connectParam(
AudioParam destinationParam, [int output, int input]) → void -
This is a variant of AudioNode.connect with a
DestinationParamargument instead of anAudioNode. Note : The W3C recommandation uses just one verb for both.inherited -
disconnect(
[AudioNode destinationParamOrOutput, int output, int input]) → void -
The
disconnect()method of the AudioNode lets you disconnect one or more nodes from the node on which the method is called. See also AudioNode.disconnectParaminherited -
disconnectParam(
AudioParam destinationParam, [int output, int input]) → void -
This is a variant of AudioNode.disconnect with a
DestinationParamargument instead of anAudioNode. Note : The W3C recommandation uses just one verb for both.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setOrientation(
num x, num y, num z) → void -
Note: The suggested replacement for this deprecated method is to instead set the
orientationX,orientationY, andorientationZattributes directly. -
setPosition(
num x, num y, num z) → void -
Note: The suggested replacement for this deprecated method is to instead set the
positionX,positionY, andpositionZattributes directly. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited